"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .llmchoice import LLMChoice, LLMChoiceTypedDict
from .llmtokenusage import LLMTokenUsage, LLMTokenUsageTypedDict
from livepeer_ai.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class LLMResponseTypedDict(TypedDict):
    id: str
    model: str
    created: int
    usage: LLMTokenUsageTypedDict
    choices: List[LLMChoiceTypedDict]


class LLMResponse(BaseModel):
    id: str

    model: str

    created: int

    usage: LLMTokenUsage

    choices: List[LLMChoice]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .llmmessage import LLMMessage, LLMMessageTypedDict
from livepeer_ai.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class LLMChoiceTypedDict(TypedDict):
    index: int
    finish_reason: NotRequired[str]
    delta: NotRequired[LLMMessageTypedDict]
    message: NotRequired[LLMMessageTypedDict]


class LLMChoice(BaseModel):
    index: int

    finish_reason: Optional[str] = ""

    delta: Optional[LLMMessage] = None

    message: Optional[LLMMessage] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing_extensions import TypedDict


class LLMMessageTypedDict(TypedDict):
    role: str
    content: str


class LLMMessage(BaseModel):
    role: str

    content: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .llmmessage import LLMMessage, LLMMessageTypedDict
from livepeer_ai.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class LLMRequestTypedDict(TypedDict):
    messages: List[LLMMessageTypedDict]
    model: NotRequired[str]
    temperature: NotRequired[float]
    max_tokens: NotRequired[int]
    top_p: NotRequired[float]
    top_k: NotRequired[int]
    stream: NotRequired[bool]


class LLMRequest(BaseModel):
    messages: List[LLMMessage]

    model: Optional[str] = ""

    temperature: Optional[float] = 0.7

    max_tokens: Optional[int] = 256

    top_p: Optional[float] = 1

    top_k: Optional[int] = -1

    stream: Optional[bool] = False



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ParamsTypedDict(TypedDict):
    r"""Initial parameters for the pipeline."""


class Params(BaseModel):
    r"""Initial parameters for the pipeline."""


class LiveVideoToVideoParamsTypedDict(TypedDict):
    subscribe_url: str
    r"""Source URL of the incoming stream to subscribe to."""
    publish_url: str
    r"""Destination URL of the outgoing stream to publish."""
    control_url: NotRequired[str]
    r"""URL for subscribing via Trickle protocol for updates in the live video-to-video generation params."""
    events_url: NotRequired[str]
    r"""URL for publishing events via Trickle protocol for pipeline status and logs."""
    model_id: NotRequired[str]
    r"""Name of the pipeline to run in the live video to video job. Notice that this is named model_id for consistency with other routes, but it does not refer to a Hugging Face model ID. The exact model(s) depends on the pipeline implementation and might be configurable via the `params` argument."""
    params: NotRequired[ParamsTypedDict]
    r"""Initial parameters for the pipeline."""


class LiveVideoToVideoParams(BaseModel):
    subscribe_url: str
    r"""Source URL of the incoming stream to subscribe to."""

    publish_url: str
    r"""Destination URL of the outgoing stream to publish."""

    control_url: Optional[str] = ""
    r"""URL for subscribing via Trickle protocol for updates in the live video-to-video generation params."""

    events_url: Optional[str] = ""
    r"""URL for publishing events via Trickle protocol for pipeline status and logs."""

    model_id: Optional[str] = ""
    r"""Name of the pipeline to run in the live video to video job. Notice that this is named model_id for consistency with other routes, but it does not refer to a Hugging Face model ID. The exact model(s) depends on the pipeline implementation and might be configurable via the `params` argument."""

    params: Optional[Params] = None
    r"""Initial parameters for the pipeline."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import io
from livepeer_ai.types import BaseModel
from livepeer_ai.utils import FieldMetadata, MultipartFormMetadata
import pydantic
from typing import IO, Optional, Union
from typing_extensions import Annotated, NotRequired, TypedDict


class AudioTypedDict(TypedDict):
    file_name: str
    content: Union[bytes, IO[bytes], io.BufferedReader]
    content_type: NotRequired[str]


class Audio(BaseModel):
    file_name: Annotated[
        str, pydantic.Field(alias="fileName"), FieldMetadata(multipart=True)
    ]

    content: Annotated[
        Union[bytes, IO[bytes], io.BufferedReader],
        pydantic.Field(alias=""),
        FieldMetadata(multipart=MultipartFormMetadata(content=True)),
    ]

    content_type: Annotated[
        Optional[str],
        pydantic.Field(alias="Content-Type"),
        FieldMetadata(multipart=True),
    ] = None


class BodyGenAudioToTextTypedDict(TypedDict):
    audio: AudioTypedDict
    r"""Uploaded audio file to be transcribed."""
    model_id: NotRequired[str]
    r"""Hugging Face model ID used for transcription."""
    return_timestamps: NotRequired[str]
    r"""Return timestamps for the transcribed text. Supported values: 'sentence', 'word', or a string boolean ('true' or 'false'). Default is 'true' ('sentence'). 'false' means no timestamps. 'word' means word-based timestamps."""


class BodyGenAudioToText(BaseModel):
    audio: Annotated[Audio, FieldMetadata(multipart=MultipartFormMetadata(file=True))]
    r"""Uploaded audio file to be transcribed."""

    model_id: Annotated[Optional[str], FieldMetadata(multipart=True)] = ""
    r"""Hugging Face model ID used for transcription."""

    return_timestamps: Annotated[Optional[str], FieldMetadata(multipart=True)] = "true"
    r"""Return timestamps for the transcribed text. Supported values: 'sentence', 'word', or a string boolean ('true' or 'false'). Default is 'true' ('sentence'). 'false' means no timestamps. 'word' means word-based timestamps."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from livepeer_ai.models.components import (
    httpmetadata as components_httpmetadata,
    livevideotovideoresponse as components_livevideotovideoresponse,
)
from livepeer_ai.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GenLiveVideoToVideoResponseTypedDict(TypedDict):
    http_meta: components_httpmetadata.HTTPMetadataTypedDict
    live_video_to_video_response: NotRequired[
        components_livevideotovideoresponse.LiveVideoToVideoResponseTypedDict
    ]
    r"""Successful Response"""


class GenLiveVideoToVideoResponse(BaseModel):
    http_meta: Annotated[
        Optional[components_httpmetadata.HTTPMetadata], pydantic.Field(exclude=True)
    ] = None

    live_video_to_video_response: Optional[
        components_livevideotovideoresponse.LiveVideoToVideoResponse
    ] = None
    r"""Successful Response"""
